@@ -161,11 +161,14 @@ class RfTestCase:
     ) -> List[List[Statement]]:
         keyword_lists: List[List[Statement]] = [[]]
         tc_index = 0
+        is_first_atomic = True
         for interaction_call in interaction_calls:
             if isinstance(interaction_call, AtomicInteractionCall):
                 if self.is_splitting_ia(interaction_call, keyword_lists, tc_index):
-                    tc_index += 1
-                    keyword_lists.append([])
+                    if not is_first_atomic:
+                        tc_index += 1
+                        keyword_lists.append([])
+                is_first_atomic = False
                 keyword_lists[tc_index].append(self._create_rf_keyword(interaction_call))
             elif (
                 isinstance(interaction_call, CompoundInteractionCall)
@@ -219,14 +222,23 @@ class RfTestCase:
                 parameters.append(value)
         return parameters
 
+    @staticmethod
+    def _create_cbr_parameters(interaction: AtomicInteractionCall) -> List[str]:
+        cbr_parameters = list(interaction.cbr_parameters.values())
+        for index, parameter in enumerate(cbr_parameters):
+            if not parameter.startswith('${'):
+                cbr_parameters[index] = f"${{{parameter}}}"
+        return cbr_parameters
+
     def _create_rf_keyword(self, interaction: AtomicInteractionCall) -> KeywordCall:
         import_prefix = self.config.fullyQualified * f"{interaction.import_prefix}."
         interaction_indent = (
             SEPARATOR * interaction.indent if self.config.logCompoundInteractions else SEPARATOR
         )
         cbv_parameters = self._create_cbv_parameters(interaction)
+        cbr_parameters = self._create_cbr_parameters(interaction)
         return KeywordCall.from_params(
-            assign=tuple(interaction.cbr_parameters.values()),
+            assign=tuple(cbr_parameters),
             name=f"{import_prefix}{interaction.name}",
             args=tuple(cbv_parameters),
             indent=interaction_indent,
