@@ -8,6 +8,7 @@ from robot.parsing.model.blocks import File
 
 from .config import Configuration
 from .log import logger
+from .utils import directory_to_zip
 
 
 def write_test_suites(test_suites: Dict[str, File], config: Configuration) -> None:
@@ -17,7 +18,7 @@ def write_test_suites(test_suites: Dict[str, File], config: Configuration) -> No
     write_test_suite_files(test_suites, generation_directory)
     if config.createOutputZip:
         directory_to_zip(generation_directory)
-    logger.info(f"Successfully written {len(test_suites)} robot files.")
+    logger.info(f"Successfully wrote {len(test_suites)} robot files.")
     logger.info(f"Path: {os.path.abspath(generation_directory)}")
 
 
@@ -46,12 +47,6 @@ def clear_generation_directory(generation_dir: Path) -> None:
 
 def write_test_suite_files(test_suites: Dict[str, File], generation_directory: Path) -> None:
     for test_suite_file in test_suites.values():
-        test_suite_file.source = os.path.join(
-            generation_directory, f"{test_suite_file.source}.robot"
-        )
-        logger.debug(os.path.relpath(test_suite_file.source))
+        test_suite_file.source = Path(generation_directory / f"{test_suite_file.source}.robot")
+        logger.debug(f"File written to {os.path.relpath(test_suite_file.source)}")
         test_suite_file.save()
-
-
-def directory_to_zip(directory: Path):
-    shutil.make_archive(str(directory), 'zip', str(directory))
